package WebGUI::i18n::German::Form_Username;
use utf8;
our $I18N = {
  'username' => {
    'lastUpdated' => '1276643133',
    'message' => 'Nutzername'
  },
  'username in use' => {
    'lastUpdated' => '1268212107',
    'message' => 'Dieser Nutzername ist bereits vergeben.'
  }
}
;

1;
